# Release information about TGSociable

version = "0.1.0"

description = "A port of the sociable Wordpress plugin"
long_description = """TurboGears Widget to add links to post pages to social bookmarking sites (Digg, Reddit, del.icio.us, &c.)"""
author = "Neil Blakey-Milner, Peter Harkins (original sociable plugin for wordpress)"
email = "nbm@nxsy.org"
copyright = "2007"

# if it's open source, you might want to specify these
url = "http://nxsy.org/code/tgsociable/"
# download_url = "http://yourcool.site/download"
license = "GPL"
